"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require('fs');
const command_1 = require("@oclif/command");
const components_filenames_1 = require("../data/components-filenames");
const sample_manager_1 = require("../sample-manager/sample-manager");
class Create extends command_1.Command {
    async run() {
        const { args, flags } = this.parse(Create);
        const sample = new sample_manager_1.default(`${flags.type}.js`);
        const fileNameToCreate = `${args.componentname}.js`;
        if (fs.existsSync(fileNameToCreate)) {
            this.log(`One file with name "${fileNameToCreate}" already exists in current directory!
Be sure you are in correct directory or choose another file name`);
            return;
        }
        sample.save(fileNameToCreate);
        this.log(`File ${fileNameToCreate} created with success B-)`);
    }
}
exports.default = Create;
Create.description = 'Create file with boilerplate jQuery code ready to deal with the component logic';
Create.examples = [
    '$ jquerygen create mycomponent',
];
Create.flags = {
    type: command_1.flags.string({
        char: 't',
        description: 'Type of component created.',
        default: 'object',
        options: components_filenames_1.default,
        required: true,
    }),
};
Create.args = [
    {
        name: 'componentname',
        required: true,
        description: 'Component file name (and class name, if class flag is added)',
    },
];
